@@ -139,13 +139,6 @@ class BootToShellTest(unittest.TestCase):
         q = Qemu.QemuCommand(QemuEfiMachine.AAVMF)
         self.run_cmd_check_shell(q.command)
 
-    @unittest.skipUnless(DPKG_ARCH == 'arm64', "Requires grub-efi-arm64")
-    @unittest.skipUnless(
-        subprocess.run(
-            ['dpkg-vendor', '--derives-from', 'Ubuntu']
-        ).returncode == 0,
-        "Debian does not provide a signed shim for arm64, see #992073"
-    )
     def test_aavmf_ms_secure_boot_signed(self):
         q = Qemu.QemuCommand(
             QemuEfiMachine.AAVMF,
@@ -157,7 +150,6 @@ class BootToShellTest(unittest.TestCase):
         q.add_disk(iso.path)
         self.run_cmd_check_secure_boot(q.command, 'aa64', True)
 
-    @unittest.skipUnless(DPKG_ARCH == 'arm64', "Requires grub-efi-arm64")
     def test_aavmf_ms_secure_boot_unsigned(self):
         q = Qemu.QemuCommand(
             QemuEfiMachine.AAVMF,
@@ -169,12 +161,38 @@ class BootToShellTest(unittest.TestCase):
         q.add_disk(iso.path)
         self.run_cmd_check_secure_boot(q.command, 'aa64', False)
 
-    def test_aavmf_snakeoil(self):
+    def test_aavmf_snakeoil_secure_boot_signed(self):
         q = Qemu.QemuCommand(
             QemuEfiMachine.AAVMF,
             variant=QemuEfiVariant.SNAKEOIL,
         )
-        self.run_cmd_check_shell(q.command)
+        shim = SignedBinary(
+            get_local_shim_path('AA64', signed=False),
+            "/usr/share/qemu-efi-aarch64/PkKek-1-snakeoil.key",
+            "/usr/share/qemu-efi-aarch64/PkKek-1-snakeoil.pem",
+            "snakeoil",
+        )
+        grub = SignedBinary(
+            get_local_grub_path('AA64', signed=False),
+            "/usr/share/qemu-efi-aarch64/PkKek-1-snakeoil.key",
+            "/usr/share/qemu-efi-aarch64/PkKek-1-snakeoil.pem",
+            "snakeoil",
+        )
+        iso = GrubShellBootableIsoImage('AA64', shim.path, grub.path)
+        q.add_disk(iso.path)
+        self.run_cmd_check_secure_boot(q.command, 'aa64', True)
+
+    def test_aavmf_snakeoil_secure_boot_unsigned(self):
+        q = Qemu.QemuCommand(
+            QemuEfiMachine.AAVMF,
+            variant=QemuEfiVariant.SNAKEOIL,
+            flash_size=QemuEfiFlashSize.DEFAULT,
+        )
+        grub = get_local_grub_path('AA64', signed=False)
+        shim = get_local_shim_path('AA64', signed=False)
+        iso = GrubShellBootableIsoImage('AA64', shim, grub)
+        q.add_disk(iso.path)
+        self.run_cmd_check_secure_boot(q.command, 'aa64', False)
 
     def test_aavmf32(self):
         q = Qemu.QemuCommand(QemuEfiMachine.AAVMF32)
@@ -198,7 +216,6 @@ class BootToShellTest(unittest.TestCase):
         )
         self.run_cmd_check_shell(q.command)
 
-    @unittest.skipUnless(DPKG_ARCH == 'amd64', "amd64-only")
     def test_ovmf_4m_ms_secure_boot_signed(self):
         q = Qemu.QemuCommand(
             QemuEfiMachine.OVMF_Q35,
@@ -211,7 +228,6 @@ class BootToShellTest(unittest.TestCase):
         q.add_disk(iso.path)
         self.run_cmd_check_secure_boot(q.command, 'x64', True)
 
-    @unittest.skipUnless(DPKG_ARCH == 'amd64', "amd64-only")
     def test_ovmf_4m_ms_secure_boot_unsigned(self):
         q = Qemu.QemuCommand(
             QemuEfiMachine.OVMF_Q35,
@@ -224,7 +240,6 @@ class BootToShellTest(unittest.TestCase):
         q.add_disk(iso.path)
         self.run_cmd_check_secure_boot(q.command, 'x64', False)
 
-    @unittest.skipUnless(DPKG_ARCH == 'amd64', "amd64-only")
     def test_ovmf_snakeoil_secure_boot_signed(self):
         q = Qemu.QemuCommand(
             QemuEfiMachine.OVMF_Q35,
@@ -246,7 +261,6 @@ class BootToShellTest(unittest.TestCase):
         q.add_disk(iso.path)
         self.run_cmd_check_secure_boot(q.command, 'x64', True)
 
-    @unittest.skipUnless(DPKG_ARCH == 'amd64', "amd64-only")
     def test_ovmf_snakeoil_secure_boot_unsigned(self):
         q = Qemu.QemuCommand(
             QemuEfiMachine.OVMF_Q35,
